@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/parser.h,v 1.4 2004/07/19 17:41:04 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/parser.h,v 1.7 2006/01/09 16:30:20 richb Exp $
  *
- *  Copyright (C) 2004-2005 Sami Pietila
+ *  Copyright (C) 2004-2006 Sami Pietila
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,6 +24,9 @@
 
 #define ANS 1
 
+#define PARSER_ERR_INVALID_BASE		10000
+#define PARSER_ERR_TOO_LONG_NUMBER 	10001
+
 struct parser_state {
     int flags;
     char *buff;
@@ -37,4 +40,6 @@ void cp(int s[MP_SIZE], int t[MP_SIZE]);
 void ret(int s[MP_SIZE]);
 void iret(int s[MP_SIZE]);
 
+void check_numbase(char *num);
+
 #endif /*PARSER_H*/
